package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.entity.TaOrder;
import com.yunzhi.shigongli.entity.TaPerson;
import com.yunzhi.shigongli.service.ITaOrderService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.shigongli.service.ITaOrderSubService;
import com.yunzhi.shigongli.entity.TaOrderSub;

/**
 * <p>
    * 子订单表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "子订单表")
@RestController
@RequestMapping("/")
public class TaOrderSubController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaOrderSubController.class);

    @Autowired
    public ITaOrderSubService iTaOrderSubService;

    @Autowired
    public ITaOrderService iTaOrderService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{plat}/taOrderSub",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taOrderSubList(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable String plat,
                                       @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaOrderSub> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaOrderSub> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaOrderSub> result = iTaOrderSubService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 订单项目退款
     * @param id
     * @return
     * @throws Exception
     */
    @DeleteMapping("/wx/orderSub/{id}/refund")
    @ApiOperation(value="订单项目退款", notes = "订单项目退款", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean refund(@ApiParam(value = "订单项目ID") @PathVariable String id) throws Exception {
        TaOrderSub taOrderSub = iTaOrderSubService.getById(id);
        if (Constants.STATUS_DELETED.equals(taOrderSub.getStatus())) {
            return ResponseBean.error("未找到退款项目", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaOrder taOrder = iTaOrderService.getById(taOrderSub.getOrderId());
        if (Constants.STATUS_DELETED.equals(taOrder.getStatus())) {
            return ResponseBean.error("未找到当前订单", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!Constants.ORDER_PAYED.equals(taOrderSub.getStatus())) {
            return ResponseBean.error("当前项目未支付", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaPerson taPerson = getCurrentPerson();

        if (!taPerson.getPersonId().equals(taOrder.getPersonId())) {
            return ResponseBean.error("您无权操作当前订单项目", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        iTaOrderSubService.refund(taPerson, taOrder, taOrderSub);

        return ResponseBean.success("操作完成");
    }

    @PutMapping("/wx/orderSub/{id}/valid")
    @ApiOperation(value="订单项目核销", notes = "订单项目核销", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean valdiation(@ApiParam(value = "订单项目ID") @PathVariable String id) throws Exception {
        TaPerson taPerson = getCurrentPerson();
        TaOrderSub taOrderSub = iTaOrderSubService.getById(id);
        TaOrder taOrder = iTaOrderService.getById(taOrderSub.getOrderId());

        if (!taPerson.getPersonId().equals(taOrder.getPersonId())) {
            return ResponseBean.error("您不能核销当前套餐", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!Constants.ORDER_PAYED.equals(taOrderSub.getStatus())) {
            return ResponseBean.error("套餐未支付或者状态异常", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        iTaOrderSubService.validation(taPerson, taOrder, taOrderSub);

        return ResponseBean.success("核销成功");
    }

//    /**
//     * 保存对象
//     * @param taOrderSub 实体对象
//     * @return
//     */
//    @RequestMapping(value="/wx/taOrderSub",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taOrderSubAdd(@ApiParam("保存内容") @RequestBody TaOrderSub taOrderSub) throws Exception{
//
//        if (iTaOrderSubService.save(taOrderSub)){
//            return ResponseBean.success(taOrderSub);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/wx/taOrderSub/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taOrderSubDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaOrderSubService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taOrderSub 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taOrderSub/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taOrderSubUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaOrderSub taOrderSub) throws Exception{
//
//        if (iTaOrderSubService.updateById(taOrderSub)){
//            return ResponseBean.success(iTaOrderSubService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taOrderSub/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taOrderSubGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaOrderSubService.getById(id));
//    }
}
