package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITaRoomOrderService;
import com.yunzhi.shigongli.entity.TaRoomOrder;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 房源订单 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "房源订单")
@RestController
@RequestMapping("/")
public class TaRoomOrderController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaRoomOrderController.class);

    @Autowired
    public ITaRoomOrderService iTaRoomOrderService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taRoomOrder",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taRoomOrderList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaRoomOrder> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaRoomOrder> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaRoomOrder> result = iTaRoomOrderService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taRoomOrder 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taRoomOrder",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taRoomOrderAdd(@ApiParam("保存内容") @RequestBody TaRoomOrder taRoomOrder) throws Exception{

        if (iTaRoomOrderService.save(taRoomOrder)){
            return ResponseBean.success(taRoomOrder);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taRoomOrder/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taRoomOrderDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaRoomOrderService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taRoomOrder 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taRoomOrder/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taRoomOrderUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaRoomOrder taRoomOrder) throws Exception{
//
//        if (iTaRoomOrderService.updateById(taRoomOrder)){
//            return ResponseBean.success(iTaRoomOrderService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taRoomOrder/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taRoomOrderGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaRoomOrderService.getById(id));
//    }
}
