package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITdTypeService;
import com.yunzhi.shigongli.entity.TdType;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 分类标签 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "分类标签")
@RestController
@RequestMapping("/")
public class TdTypeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdTypeController.class);

    @Autowired
    public ITdTypeService iTdTypeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{plat}/tdType",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tdTypeList(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable String plat,
                                   @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                   @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                   @ApiParam("分类名称") @RequestParam(value ="typeName", required = false) String typeName) throws Exception{

        IPage<TdType> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TdType> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(typeName), "type_name", "%"+typeName+"%");
        queryWrapper.eq("wx".equals(plat), "status", Constants.STATUS_NORMAL);
        queryWrapper.gt("admin".equals(plat), "status", Constants.STATUS_DELETED);
        queryWrapper.orderByDesc("weight");
        queryWrapper.orderByDesc("create_date");

        IPage<TdType> result = iTdTypeService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param tdType 实体对象
     * @return
     */
    @RequestMapping(value="/admin/tdType",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean tdTypeAdd(@ApiParam("保存内容") @RequestBody TdType tdType) throws Exception{

        if (iTdTypeService.save(tdType)){
            return ResponseBean.success(tdType);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/tdType/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean tdTypeDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTdTypeService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param tdType 实体对象
     * @return
     */
    @RequestMapping(value="/admin/tdType/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean tdTypeUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TdType tdType) throws Exception{

        if (iTdTypeService.updateById(tdType)){
            return ResponseBean.success(iTdTypeService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/tdType/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tdTypeGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTdTypeService.getById(id));
    }
}
