package com.yunzhi.shigongli.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.entity.TaHotelAccount;
import com.yunzhi.shigongli.entity.TaHotelAccountLog;
import com.yunzhi.shigongli.mapper.TaHotelAccountLogMapper;
import com.yunzhi.shigongli.mapper.TaHotelAccountMapper;
import com.yunzhi.shigongli.service.ITaHotelAccountService;

import org.omg.PortableInterceptor.ACTIVE;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;

/**
 * <p>
 * 民宿账户 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaHotelAccountServiceImpl extends BaseServiceImpl<TaHotelAccountMapper, TaHotelAccount> implements ITaHotelAccountService {

    @Autowired
    TaHotelAccountMapper taHotelAccountMapper;

    @Autowired
    TaHotelAccountLogMapper taHotelAccountLogMapper;

    @Async
    @Override
    public void initSystemAccount() {
        try {
            TaHotelAccount account = getById(Constants.SYSTEM_ACCOUNT_ID);
            if (null == account) {
                account = new TaHotelAccount();
                account.setAccountId(Constants.SYSTEM_ACCOUNT_ID);
                account.setHotelId(Constants.SYSTEM_ACCOUNT_ID);
                save(account);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public TaHotelAccount getByHotel(String hotelId) {
        LambdaQueryWrapper<TaHotelAccount> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaHotelAccount::getHotelId, hotelId);

        return getOne(queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean commissionSettlement(TaHotelAccount taHotelAccount, Integer charges) throws Exception {
        int cnt = taHotelAccountMapper.commissionSettlement(taHotelAccount.getAccountId(), charges);
        if (cnt < 1) {
            throw new Exception("待结算佣金不足");
        }

        TaHotelAccountLog accountLog = new TaHotelAccountLog();
        accountLog.setAccountId(taHotelAccount.getAccountId());
        accountLog.setHotelId(taHotelAccount.getHotelId());
        accountLog.setSignType(Constants.ACCOUNT_EXPENSE);
        accountLog.setAmountType(Constants.ACCOUNT_SETTLEMENT);
        accountLog.setAmount(-charges);
        accountLog.setCreateDate(LocalDateTime.now());

        taHotelAccountLogMapper.insert(accountLog);

        return true;
    }
}
