package com.yunzhi.shigongli.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.entity.TaHotel;
import com.yunzhi.shigongli.entity.TaHotelAccount;
import com.yunzhi.shigongli.mapper.TaHotelAccountMapper;
import com.yunzhi.shigongli.mapper.TaHotelMapper;
import com.yunzhi.shigongli.service.ITaHotelService;

import com.yunzhi.shigongli.vo.HotelListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 民宿 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaHotelServiceImpl extends BaseServiceImpl<TaHotelMapper, TaHotel> implements ITaHotelService {

    @Autowired
    TaHotelMapper hotelMapper;

    @Autowired
    TaHotelAccountMapper accountMapper;

    @Override
    public List<TaHotel> getByName(String hotelName) {
        LambdaQueryWrapper<TaHotel> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaHotel::getHotelName, hotelName)
                .gt(TaHotel::getStatus, Constants.STATUS_DELETED)
                .orderByDesc(TaHotel::getCreateDate);
        return list(queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean createNew(TaHotel taHotel) throws Exception {
        save(taHotel);

        TaHotelAccount account = new TaHotelAccount();
        account.setHotelId(taHotel.getHotelId());
        accountMapper.insert(account);

        return true;
    }

    @Override
    public IPage<HotelListVO> getVOListBy(IPage<TaHotel> pg, String hotelName) {
        return hotelMapper.getVOListBy(pg, hotelName);
    }
}
