package com.yunzhi.shigongli.service.impl;

import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.WxPayUtils;
import com.yunzhi.shigongli.entity.*;
import com.yunzhi.shigongli.mapper.*;
import com.yunzhi.shigongli.service.ITaOrderSubService;

import org.omg.PortableInterceptor.ACTIVE;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 子订单表 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaOrderSubServiceImpl extends BaseServiceImpl<TaOrderSubMapper, TaOrderSub> implements ITaOrderSubService {

    @Autowired
    WxPayUtils wxPayUtils;

    @Autowired
    TaOrderSubMapper taOrderSubMapper;

    @Autowired
    TaOrderCommissionMapper commissionMapper;

    @Autowired
    TaPersonRecommenderMapper recommenderMapper;

    @Autowired
    TaShopAccountMapper shopAccountMapper;

    @Autowired
    TaShopAccountLogMapper shopAccountLogMapper;

    @Autowired
    TaHotelAccountMapper hotelAccountMapper;

    @Autowired
    TaHotelAccountLogMapper hotelAccountLogMapper;

    /**
     * 订单项目退款
     * @param person
     * @param taOrder
     * @param taOrderSub
     * @throws Exception
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void refund(TaPerson person, TaOrder taOrder, TaOrderSub taOrderSub) throws Exception {
        wxPayUtils.refund(taOrder, taOrderSub);

        // 更新表
        taOrderSubMapper.updateStatus(taOrderSub.getSubOrderId(), Constants.ORDER_REFUND);

        // 后面的业务, 比如退款之后, 扣除个人账户之类的
        // 交给退款成功之后的回调处理
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void validation(TaPerson taPerson, TaOrder taOrder, TaOrderSub taOrderSub) throws Exception {
        // 先更新状态
        taOrderSubMapper.updateVerified(taOrderSub.getSubOrderId(), 1);

        // 获取当前人员的推荐人
        TaPersonRecommender recommender = recommenderMapper.getAcitveRecommender(taPerson.getPersonId());

        // 查询分佣表
        List<TaOrderCommission> commissionList = commissionMapper.getListByOrderSub(taOrderSub.getSubOrderId());

        for (TaOrderCommission commission : commissionList) {
            // 流量抽成
            if (Constants.COMMISSION_TRAFFIC.equals(commission.getCommissionType())) {
                if (Constants.RECOMMEND_SHOP.equals(recommender.getFromType())) {
                    // 如果是商户推荐的
                    createShopAccountLog(recommender.getRecommender(), commission);
                } else if (Constants.RECOMMEND_HOTEL.equals(recommender.getFromType())) {
                    // 如果是民宿推荐的
                    createHotelAccountLog(recommender.getRecommender(), commission);
                }
            }

            // 平台抽成
            if (Constants.COMMISSION_PLATFORM.equals(commission.getCommissionType())) {
                // 平台账户暂时用民宿代替
                createHotelAccountLog(Constants.SYSTEM_ACCOUNT_ID, commission);
            }
        }
    }

    /**
     * 商铺抽成入账户
     * @param shopId
     * @param commission
     * @throws Exception
     */
    private void createShopAccountLog(String shopId, TaOrderCommission commission) throws Exception {
        TaShopAccount account = shopAccountMapper.selectByShop(shopId);

        // 先插入明细
        TaShopAccountLog accountLog = new TaShopAccountLog();
        accountLog.setAccountId(account.getAccountId());
        accountLog.setShopId(shopId);
        accountLog.setSignType(commission.getCharge() > 0 ? Constants.ACCOUNT_INCOME : Constants.ACCOUNT_EXPENSE);
        accountLog.setAmountType(Constants.ACCOUNT_COMMISSION);
        accountLog.setAmount(commission.getCharge());
        accountLog.setTargetType(Constants.TARGET_ORDER);
        accountLog.setTargetId(commission.getOrderId());
        accountLog.setOrderId(commission.getOrderId());
        accountLog.setSubOrderId(commission.getSubOrderId());
        accountLog.setCreateDate(LocalDateTime.now());
        shopAccountLogMapper.insert(accountLog);

        // 再累计到账户
        shopAccountMapper.updateCommission(account.getAccountId(), accountLog.getAmount());
    }

    /**
     * 民宿抽成入账户
     * @param hotelId
     * @param commission
     * @throws Exception
     */
    private void createHotelAccountLog(String hotelId, TaOrderCommission commission) throws Exception {
        TaHotelAccount account = hotelAccountMapper.selectByHotel(hotelId);

        // 先插入明细
        TaHotelAccountLog accountLog = new TaHotelAccountLog();
        accountLog.setAccountId(account.getAccountId());
        accountLog.setHotelId(hotelId);
        accountLog.setSignType(commission.getCharge() > 0 ? Constants.ACCOUNT_INCOME : Constants.ACCOUNT_EXPENSE);
        accountLog.setAmountType(Constants.ACCOUNT_COMMISSION);
        accountLog.setAmount(commission.getCharge());
        accountLog.setTargetType(Constants.TARGET_ORDER);
        accountLog.setTargetId(commission.getOrderId());
        accountLog.setOrderId(commission.getOrderId());
        accountLog.setSubOrderId(commission.getSubOrderId());
        accountLog.setCreateDate(LocalDateTime.now());
        hotelAccountLogMapper.insert(accountLog);

        // 再累计到账户
        hotelAccountMapper.updateCommission(account.getAccountId(), accountLog.getAmount());
    }
}
